// React imports
import React, { ReactNode, useImperativeHandle, useRef } from 'react'

// Chakra imports
import { Text, Flex, useColorModeValue } from '@chakra-ui/react'

// Formik imports
import { Formik, Form, FormikValues, FormikProps } from 'formik';

// Components imports
import Card from '@/components/card/Card'
import SubmitButton from '@/components/buttons/submit'

// Form props interface 
interface FormProps {
  children: ReactNode;
  submitForm: (formData: any, formik: any) => void;
  initialValues: object;
  validationSchema: object;
  heading?: string;
}

const FormComponent = React.forwardRef(({ children, submitForm, initialValues, validationSchema, heading }: FormProps, ref) => {
  // Chakra color mode
  const textColor = useColorModeValue("secondaryGray.900", "white");
  const currentFormRef = useRef<FormikProps<object>>(null);

  const externalHandleSubmit = () => {
    currentFormRef.current.handleSubmit();
  };

  useImperativeHandle(ref, () => ({
    externalHandleSubmit,
  }));

  return (
    <Card flexDirection="column" w="100%" px="0px" overflowX={{ sm: "scroll", lg: "hidden" }}>
      <Formik
        innerRef={currentFormRef}
        validateOnChange={false} // Add this line
        enableReinitialize
        // Define your initial form values here
        initialValues={initialValues}
        // Validate form values here
        validationSchema={validationSchema}
        onSubmit={async (values, formik) => {
          // Handle form submission here
          await submitForm(values, formik);
        }}>
        <Form>
          {/* Heading */}
          {heading && (
            <Flex px="25px" justify="flex-start" mb="30px" align="center">
              <Text color={textColor} fontSize="22px" fontWeight="700" lineHeight="100%">
                {heading}
              </Text>
            </Flex>
          )}

          {/* Form Fields */}
          <Flex px="25px" flexDir="column" w={{ lg: "100%" }}>
            {children}
          </Flex>

          {/* Submit */}
          {/* <Flex px='25px' justify='flex-end' mb='20px' align='center'>
          <SubmitButton text={isEdit ? 'Save' : 'Add'}/>
        </Flex> */}
        </Form>
      </Formik>
    </Card>
  );
});

FormComponent.displayName = "FormComponent";

export default FormComponent;

